pyxmpp.jabber.delay

Package pyxmpp :: Package jabber :: Module delay |
[hide private]

# Module delay

source code

Delayed delivery mark (jabber:x:delay) handling.

Normative reference:
  - JEP 91

Classes | [hide private]
| Delay Delayed delivery tag.

Functions | [hide private]
`list` of Delay |
get_delays(stanza) Get jabber:x:delay elements from the stanza. | source code
Delay |
get_delay(stanza) Get the oldest jabber:x:delay elements from the stanza. | source code

Variables | [hide private]
| __revision__ = ``'``$Id: delay.py 714 2010-04-05 10:20:10Z jajcus $``'``
| DELAY_NS = ``'``jabber:x:delay``'``
| __package__ = ``'``pyxmpp.jabber``'``

Imports: libxml2, time, datetime, JID, to_utf8, from_utf8, get_node_ns_uri, datetime_utc_to_local, datetime_local_to_utc, StanzaPayloadObject, BadRequestProtocolError, JIDMalformedProtocolError, JIDError

Function Details | [hide private]

### get_delays(stanza) | source code
Get jabber:x:delay elements from the stanza. Parameters: `stanza` (pyxmpp.stanza.Stanza) - a, probably delayed, stanza. Returns: `list` of Delay list of delay tags sorted by the timestamp.

### get_delay(stanza) | source code
Get the oldest jabber:x:delay elements from the stanza. The return value, if not `None`, contains a quite reliable timestamp of a delayed (e.g. from offline storage) message. Parameters: `stanza` (pyxmpp.stanza.Stanza) - a, probably delayed, stanza. Returns: Delay the oldest delay tag of the stanza or `None`.